/* ARBOMB */

/* Archive Bomb test-analyzer */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <syslog.h>

#include "arbomb_utils.h"
#include "arbomb_api.h"
#include "logger.h"

#define _ARBOMB_USAGE "Arbomb - v0.0.2\nUsage: arbomb -f <archive to test> [-u KBytes] [-r ratio] [-c filecount] [-v]\n\
\t-f <archive to test> : The file which needs to be tested for volatility\n\
\t-u <KBytes> : Maximum size in KBytes which a single file can be\n\
\t-r <ratio> : Iteger ratio maxmimum between compressed size and uncompressed size\n\
\t-c <filecount> : Maximum number of files permitted\n\
\t-c : Log to syslog\n\
\t-d : Activate debugging mode\n\
\t-v : Arbomb version\n\n"

#define _VERSION "0.0.1\n"

#define _ARBOMB_EXIT_INVALID_PARMS 50
#define _ARBOMB_EXIT_INSUFFICIENT_PARMS 51
#define _ARBOMB_EXIT_VERSION 60

#define _ARBOMB_UCSIZE_LIMIT 	'u'
#define _ARBOMB_RATIO_LIMIT  	'r'
#define _ARBOMB_FCOUNT_LIMIT 	'c'
#define _ARBOMB_INPUTFILE 		'f'
#define _ARBOMB_SYSLOG			's'
#define _ARBOMB_DEBUG			'd'
#define _ARBOMB_VERSION			'v'

char *_inputfile;
int _debugging;
int _ratio_limit;
int _ucsize_limit;
int _fcount_limit;


/*------------------------------------------------------------------------
 Procedure:     ARBOMB_parse_params ID:1
 Purpose:       Parse any command line params to ArBomb
 Input:
 Output:
 Errors:
------------------------------------------------------------------------*/
int ARBOMB_parse_params( int argc, char **argv, struct arbomb_limits *abl )
{
	int result = 0;
	int cc=1;

	if (argc == 1)
	{
		fprintf(stdout,_ARBOMB_USAGE);
		exit(1);
	}


	while (cc < argc)
	{
		if (*argv[cc] == '-')
		{
			cc++;
			switch (argv[cc-1][1]) {
				case _ARBOMB_INPUTFILE:
					_inputfile = argv[cc];
					break;
				case _ARBOMB_UCSIZE_LIMIT:
					abl->single_ucsize = atoi(argv[cc]) *1024;
					break;
				case _ARBOMB_FCOUNT_LIMIT:
					abl->archive_filecount = atoi(argv[cc]);
					break;
				case _ARBOMB_RATIO_LIMIT:
					abl->single_ratio = atoi(argv[cc]);
					break;
				case _ARBOMB_SYSLOG:
					LOGGER_set_output_mode(_LOGGER_SYSLOG);
					LOGGER_set_syslog_mode(LOG_MAIL|LOG_INFO);
					cc--;
				case _ARBOMB_DEBUG:
					ABAPI_set_debug(1);
					cc--;
					break;
				case _ARBOMB_VERSION:
					fprintf(stdout,_VERSION);
					exit(_ARBOMB_EXIT_VERSION);
					break;
				default:
					LOGGER_log("ARBOMB_parse_params: Unknown command line parameter\n",argv[cc]);
					fprintf(stdout,_ARBOMB_USAGE);
					exit(_ARBOMB_EXIT_INVALID_PARMS);
					break;
			}
		}

		cc++;
	}


	return result;
}


/*------------------------------------------------------------------------
 Procedure:     main ID:1
 Purpose:       ArBomb main entry point.
 Input:
 Output:
 Errors:
------------------------------------------------------------------------*/
int main( int argc, char **argv )
{
	int result = 0;
	struct arbomb_limits _abl, *abl, _lcs, *lcs;

// Start initialisation phase -------------
	abl = &_abl;
	lcs = &_lcs;

	abl->single_ucsize=0;
	abl->single_ratio=0;
	abl->archive_filecount=0;

	_AB_test_ucsize = 1;
	_AB_test_ratio = 1;
	_AB_test_fcount = 1;

	// Set our logging output.
	LOGGER_set_output_mode( _LOGGER_STDOUT );

	// Parse out parameters as passed via command line.
	ARBOMB_parse_params( argc, argv, abl );

	result = ABAPI_test_archive(_inputfile, abl, lcs);

	// Report Details.
	if (result) ABAPI_report(result, lcs, 0);

	// Make sure we return the result of the tests.
	return result;
}
