#include <stdio.h>
#include <stdlib.h>

#include "arbomb_utils.h"
#include "arbomb_api.h"
#include "logger.h"
#include "ziptest.h"




int ABAPI_set_debug( int level )
{
	ZT_set_debug(1);
	return 0;
}

/*------------------------------------------------------------------------
Procedure:     AB_report ID:1
Purpose:       Reports the results gained from the archive tests.
Input:         exitcode: The code we're reporting for
arbomb_limits: The details of the archive
reportmode: Determines how we report to user (not yet used)
Output:
Errors:
------------------------------------------------------------------------*/
int ABAPI_report( int exitcode, struct arbomb_limits *lcs, int reportmode )
{

	switch (exitcode) {
	case 0:
		fprintf(stdout,"All ok.\n");
		break;
	case AB_ERR_RATIO:
		LOGGER_log("Ratio limit break on file %s (%dKb->%dKb (1:%f)\n"\
				, lcs->filename\
				, lcs->single_csize >> 10\
				, lcs->single_ucsize >> 10\
				, lcs->single_ratio\
				);
		break;
	case AB_ERR_UCSIZE:
		LOGGER_log("Uncompressed size limit break on file %s (%dKb->%dKb (1:%f)\n"\
				, lcs->filename\
				, lcs->single_csize >> 10\
				, lcs->single_ucsize >> 10\
				, lcs->single_ratio\
				);
		break;
	case AB_ERR_FCOUNT:
		LOGGER_log("File count limit breached\n");
		break;
	case AB_ERR_INTERNAL:
		LOGGER_log("Error in archive testing (see previous details)\n");
		break;
	default:
		LOGGER_log("Unknown Error response %d\n",exitcode);
	}

	return exitcode;
}




/*------------------------------------------------------------------------
 Procedure:     ABAPI_test_archive ID:1
 Purpose:       Tests a given archive file with the limits supplied
 Input:
 Output:
 Errors:
------------------------------------------------------------------------*/
int ABAPI_test_archive( char *fname, struct arbomb_limits *abl, struct arbomb_limits *lcs )
{
	int result = 0;

	// Test our ZIP files
	if (ZT_iszip(fname)) result = ZT_test( fname, abl, lcs );

	// Make sure we return the result of the tests.
	return result;
}

//--END.


